utils::globalVariables(c("%>%",
                         "SSlogis5",
                         "aes",
                         "coef",
                         "filter",
                         "geom_line",
                         "ggplot",
                         "ggtitle",
                         "group_by",
                         "guides",
                         "hlme",
                         "labs",
                         "na.omit",
                         "normcdf",
                         "quantile",
                         "row_number",
                         "saemix",
                         "saemixControl",
                         "saemixData",
                         "saemixModel",
                         "sample_n",
                         "scale_x_continuous",
                         "sqldf",
                         "as.formula",
                         "time_pos",
                         "legend",
                         "points",
                         "round",
                         'knitr',
                         "nlraa",
                         'write.table',
                         'read.table',
                         'dummy_cols',
                         "which",
                         "pmax"))
